@@ -15,6 +15,7 @@
 #define AUDIO_OUTPUT_CODEC_NAME "pcm_s32le"
 #define DEFAULT_AUDIO_OUTPUT_BIT_RATE 0
 #define DEFAULT_X264_OUTPUT_BIT_RATE 4500  // 5 Mbit after making room for some audio and TCP overhead.
+#define DEFAULT_AV1_OUTPUT_BIT_RATE 4500  // Same.
 
 #define LOCAL_DUMP_PREFIX "record-"
 #define LOCAL_DUMP_SUFFIX ".nut"
@@ -27,8 +28,13 @@
 // In number of frames. Comes in addition to any internal queues in x264
 // (frame threading, lookahead, etc.).
 #define X264_QUEUE_LENGTH 50
+#define AV1_QUEUE_LENGTH 50
 
 #define X264_DEFAULT_PRESET "ultrafast"
 #define X264_DEFAULT_TUNE "film"
 
+#define DEFAULT_AV1_PRESET 12
+#define DEFAULT_AV1_FPS_NUM 60000
+#define DEFAULT_AV1_FPS_DEN 1001
+
 #endif  // !defined(_DEFS_H)
